# Therapist

A lint suite runner with Git-aware capabilities and a smart pre-commit hook. 

![PyPI](https://img.shields.io/pypi/v/therapist.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/therapist.svg)

[![CircleCI](https://img.shields.io/circleci/project/github/rehandalal/therapist.svg)](https://circleci.com/gh/rehandalal/therapist)
[![Codecov](https://img.shields.io/codecov/c/gh/rehandalal/therapist.svg)](https://codecov.io/gh/rehandalal/therapist)
[![Documentation](https://img.shields.io/readthedocs/therapist/latest.svg)](http://therapist.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/rehandalal/therapist/shield.svg)](https://pyup.io/repos/github/rehandalal/therapist/)

## Documentation

Full documentation for this tool is available at: 
http://therapist.readthedocs.io/
